==> stumpf-0.0.8.dev100.tar.gz: stumpf-0.0.8.dev100/stumpf/mock_auth.py <==
"""
This module defines a "mocked" google oauth provider by overriding flask_dance
class methods that communicate with google's service.  With the mocked oauth
provider `/auth/google` directly redirects to `/auth/google/authorized`.

The oauth session object contains a hard-coded response that returns mock user
information in a format expected by flask_dance's oauth handler.
"""
from datetime import datetime, timedelta
import json
import secrets

from flask import current_app, redirect, url_for
from flask_dance.consumer import OAuth2ConsumerBlueprint, OAuth2Session, oauth_authorized
from flask_dance.consumer.backend.sqla import SQLAlchemyBackend
from flask_dance.utils import timestamp_from_datetime
from flask_login import current_user
from requests import Response

from stumpf.auth import google_logged_in
from stumpf.models import db, OAuth


class MockOAuthSession(OAuth2Session):
    def request(self, method, url, **kwargs):
        if method == 'GET' and url == '/oauth2/v2/userinfo':
            resp = Response()
            resp.status_code = 200
            resp._content = json.dumps({
                'hd': 'kitware.com',
                'id': 'mock-google-id',
                'email': 'test@kitware.com'
            }).encode('utf-8')
            return resp
        return super().request(method, url, **kwargs)

    @property
    def authorized(self):
        self.load_token()
        return True


class MockOAuth2Blueprint(OAuth2ConsumerBlueprint):
    def login(self):
        if current_app.config.get('ENV') != 'development':
            raise Exception('Mock auth should not be used in production')
        return redirect(url_for('.authorized'))

    def authorized(self):
        token = {
            'access_token': secrets.token_hex(),
            'id_token': 'mock-id-token',
            'expires_in': 3600,
            'expires_at': timestamp_from_datetime(datetime.utcnow() + timedelta(seconds=3600))
        }
        return oauth_authorized.send(self, token=token)[0][1]


mock_auth_bp = MockOAuth2Blueprint(
        'google', __name__,
        session_class=MockOAuthSession,
        backend=SQLAlchemyBackend(OAuth, db.session, user=current_user)
)


@oauth_authorized.connect_via(mock_auth_bp)
def google_logged_in_decorated(*args, **kwargs):
    return google_logged_in(*args, **kwargs)

==> stumpf-0.1.13.dev2.tar.gz: stumpf-0.1.13.dev2/stumpf/mock_auth.py <==
"""
This module defines a "mocked" google oauth provider by overriding flask_dance
class methods that communicate with google's service.  With the mocked oauth
provider `/auth/google` directly redirects to `/auth/google/authorized`.

The oauth session object contains a hard-coded response that returns mock user
information in a format expected by flask_dance's oauth handler.
"""
from datetime import datetime, timedelta
import json
import secrets

from flask import current_app, redirect, url_for
from flask_dance.consumer import OAuth2ConsumerBlueprint, OAuth2Session, oauth_authorized
from flask_dance.consumer.storage.sqla import SQLAlchemyStorage
from flask_dance.utils import timestamp_from_datetime
from flask_login import current_user
from requests import Response

from stumpf.auth import google_logged_in
from stumpf.models import db, OAuth


class MockOAuthSession(OAuth2Session):
    def request(self, method, url, **kwargs):
        if method == 'GET' and url == '/oauth2/v2/userinfo':
            resp = Response()
            resp.status_code = 200
            resp._content = json.dumps({
                'hd': 'kitware.com',
                'id': 'mock-google-id',
                'email': 'test@kitware.com'
            }).encode('utf-8')
            return resp
        return super().request(method, url, **kwargs)

    @property
    def authorized(self):
        self.load_token()
        return True


class MockOAuth2Blueprint(OAuth2ConsumerBlueprint):
    def login(self):
        if current_app.config.get('ENV') != 'development':
            raise Exception('Mock auth should not be used in production')
        return redirect(url_for('.authorized'))

    def authorized(self):
        token = {
            'access_token': secrets.token_hex(),
            'id_token': 'mock-id-token',
            'expires_in': 3600,
            'expires_at': timestamp_from_datetime(datetime.utcnow() + timedelta(seconds=3600))
        }
        return oauth_authorized.send(self, token=token)[0][1]


mock_auth_bp = MockOAuth2Blueprint(
        'google', __name__,
        session_class=MockOAuthSession,
        storage=SQLAlchemyStorage(OAuth, db.session, user=current_user)
)


@oauth_authorized.connect_via(mock_auth_bp)
def google_logged_in_decorated(*args, **kwargs):
    return google_logged_in(*args, **kwargs)
